- creatinine
Numeric vector. Serum creatinine, could be expressed in "micromol/L", "mmol/L" or "mg/dL". Units of measurement should be defined in variable creatinine_units (if not defined explicitly by user, the default value is "micromol/L").
- cystatin
Numeric vector. Serum cystatin, could be expressed in "mg/L" or "nanomol/L". Units of measurement should be defined in variable cystatin_units (if not defined explicitly by user, the default value is "mg/L").
- age
Numeric vector. Age, in years.
- sex
Vector. The value of variable refers to the parameters label_sex_male and label_sex_female.
- alpha
Numeric vector. Alpha coefficient for the combined creatinine-cystatin equation. By default is equal to 0.5.
- creatinine_units
Character string. Units in which serum creatinne is expressed. Could be one of the following: "micromol/L", "mmol/L" or "mg/dL".
- cystatin_units
Character string. Units in which serum cystatin is expressed. Could be one of the following: "mg/L" or "nanomol/L"
- equation_type
Character string. Whether to use "precise" or "simplified" equation.
- label_sex_male
List. Label(s) for definition(s) of male sex.
- label_sex_female
List. Label(s) for definition(s) of female sex.
- max_age
Numeric. Maximal age suitable for the equation application, in years. By default is 100 years, but change this value in case you would like to apply equation to older persons.