Learn R Programming

kidney.epi (version 1.3.0)

matrix.read_excel_to_named_matrix: Read Excel file and convert it to matrix with row and column names.

Description

Read Excel file and convert it to matrix with row and column names.

Usage

matrix.read_excel_to_named_matrix(file_path, sheet_name = NULL)

Value

Excel file saved to a specified folder.

Arguments

file_path

character. Path to Excel file.

sheet_name

character. Name of Excel sheet. Optional, if there is only one sheet with data, the function will read it with no need to specifying the sheet name.

Details

Read Excel file and convert it to matrix with row and column names.