Save a named matrix as an Excel file.
matrix.save_named_matrix_to_excel(
matrix_data,
file_path,
sheet_name = "Sheet1",
save_type = "new"
)Excel file saved to a specified folder.
matrix. Matrix for saving.
character. Path to the Excel file.
character. Name of the Excel sheet.
character. Defines whether the Excel file should be created or overwritten (save_type = "new"), or new sheet should be added to the existing Excel file (save_type = "add").
Save a named matrix as an Excel file.