Read Excel file and convert it to matrix with row and column names.
matrix.read_excel_to_named_matrix(file_path, sheet_name = NULL)Excel file saved to a specified folder.
character. Path to Excel file.
character. Name of Excel sheet. Optional, if there is only one sheet with data, the function will read it with no need to specifying the sheet name.
Read Excel file and convert it to matrix with row and column names.